@@ -79,19 +79,19 @@ public:
     /// <summary>
     /// STL-style typedefs
     /// </summary>
-    typedef typename inner_container::key_type key_type;
-    typedef typename inner_container::key_compare key_compare;
-    typedef typename inner_container::allocator_type allocator_type;
-    typedef typename inner_container::size_type size_type;
-    typedef typename inner_container::difference_type difference_type;
-    typedef typename inner_container::pointer pointer;
-    typedef typename inner_container::const_pointer const_pointer;
-    typedef typename inner_container::reference reference;
-    typedef typename inner_container::const_reference const_reference;
-    typedef typename inner_container::iterator iterator;
-    typedef typename inner_container::const_iterator const_iterator;
-    typedef typename inner_container::reverse_iterator reverse_iterator;
-    typedef typename inner_container::const_reverse_iterator const_reverse_iterator;
+    typedef inner_container::key_type key_type;
+    typedef inner_container::key_compare key_compare;
+    typedef inner_container::allocator_type allocator_type;
+    typedef inner_container::size_type size_type;
+    typedef inner_container::difference_type difference_type;
+    typedef inner_container::pointer pointer;
+    typedef inner_container::const_pointer const_pointer;
+    typedef inner_container::reference reference;
+    typedef inner_container::const_reference const_reference;
+    typedef inner_container::iterator iterator;
+    typedef inner_container::const_iterator const_iterator;
+    typedef inner_container::reverse_iterator reverse_iterator;
+    typedef inner_container::const_reverse_iterator const_reverse_iterator;
 
     /// <summary>
     /// Constructs an empty set of HTTP headers.
@@ -145,13 +145,15 @@ public:
     template<typename _t1>
     void add(const key_type& name, const _t1& value)
     {
-        if (has(name))
+        auto printedValue = utility::conversions::details::print_string(value);
+        auto& mapVal = m_headers[name];
+        if (mapVal.empty())
         {
-            m_headers[name].append(_XPLATSTR(", ")).append(utility::conversions::details::print_string(value));
+            mapVal = std::move(printedValue);
         }
         else
         {
-            m_headers[name] = utility::conversions::details::print_string(value);
+            mapVal.append(_XPLATSTR(", ")).append(std::move(printedValue));
         }
     }
 
@@ -212,20 +214,12 @@ public:
     bool match(const key_type &name, _t1 &value) const
     {
         auto iter = m_headers.find(name);
-        if (iter != m_headers.end())
-        {
-            // Check to see if doesn't have a value.
-            if(iter->second.empty())
-            {
-                bind_impl(iter->second, value);
-                return true;
-            }
-            return bind_impl(iter->second, value);
-        }
-        else
+        if (iter == m_headers.end())
         {
             return false;
         }
+
+        return bind_impl(iter->second, value) || iter->second.empty();
     }
 
     /// <summary>
@@ -311,6 +305,7 @@ private:
         ref = utility::conversions::to_utf16string(text);
         return true;
     }
+
     bool bind_impl(const key_type &text, std::string &ref) const
     {
         ref = utility::conversions::to_utf8string(text);
